marktools.detach_marks_attached_to_components_in_expr
=====================================================

.. autofunction:: abjad.tools.marktools.detach_marks_attached_to_components_in_expr.detach_marks_attached_to_components_in_expr
   :noindex:
